@@ -1,5 +1,4 @@
-from kiwi.apps import KiwiCoder, Step, Vol, Container,  MeasureHardware
-from kiwi.plugin.hardware.instrum import FlowMeter
+from src.kiwi import KiwiCoder
 
 
 # def test_app_config():
