@@ -1,4 +1,4 @@
-from kiwi.util import EventBus
+from src.kiwi.util import EventBus
 
 bus = EventBus()
 
