@@ -1,8 +1,6 @@
-from threading import Thread
-
-from kiwi.apps import KiwiCoder, Step, Container, measure_fluid
-from kiwi.core.bio_quantity import Volume
-from kiwi.plugin.hardware.instrum import FlowMeter
+from src.kiwi import KiwiCoder, Step, Container, measure_fluid
+from src.kiwi.core.bio_quantity import Volume
+from src.kiwi.plugin.hardware.instrum import FlowMeter
 
 
 class MockFlowMeter:
